(define-module (glicid packages linux)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system go)
  #:use-module (gnu packages backup)
  #:use-module (gnu packages compression)
  #:use-module (gnu packages cryptsetup)
  #:use-module (gnu packages golang)
  #:use-module ((gnu packages linux) #:prefix gnu:)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages python)
  #:use-module (gnu packages tls)
)

(define-public rdma-core-newer-37.1
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-newer" ))
    (version "37.1")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/linux-rdma/rdma-core/releases/download/v" version "/rdma-core-" version ".tar.gz"))
        (sha256 (base32 "1hjwagf5x48vgshy5s01qjlzjr8kmxpflfcvh8pgj3zbj82zzxiz"))
      )
    )
  )
)

(define-public rdma-core-newer-38.0
  (package
    (inherit gnu:rdma-core)
    (name (string-append (package-name gnu:rdma-core) "-newer" ))
    (version "38.0")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/linux-rdma/rdma-core/releases/download/v" version "/rdma-core-" version ".tar.gz"))
        (sha256 (base32 "043vybwx9kz4mbbmnj0jzkzsw02vzhkkjc5j3yjdiiqkmsgwr3cs"))
      )
    )
  )
)

(define local-rdma-core rdma-core-newer-38.0)

(define-public rdma-core-latest local-rdma-core)

(define-public libfabric-newer-1.13.1
  (package
    (inherit gnu:libfabric)
    (version "1.13.1")
    (name (string-append (package-name gnu:libfabric) "-newer" ))
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/ofiwg/libfabric/releases/download/v" version "/libfabric-" version ".tar.bz2"))
        (sha256 (base32 "03nkhqjjyw3hwhxrn7rg30qc1gzc1r7p7lymyz5s96m3qhwfsvlf"))
      )
    )
  )
)

(define-public libfabric-newer-1.14.0
  (package
    (inherit gnu:libfabric)
    (version "1.14.0")
    (name (string-append (package-name gnu:libfabric) "-newer" ))
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/ofiwg/libfabric/releases/download/v" version "/libfabric-" version ".tar.bz2"))
        (sha256 (base32 "16klkzkg04wb699mqpi8mn2r8sqzj35zalynbdazyg4ghj4169pw"))
      )
    )
  )
)

(define local-libfabric libfabric-newer-1.14.0)

(define-public libfabric-latest local-libfabric)

(define-public apptainer-singularity-3.8.5
  (package
    (name "singularity")
    (version "3.8.5")
    (source
      (origin
        (method url-fetch)
        (uri (string-append "https://github.com/apptainer/singularity/releases/download/v" version "/singularity-" version ".tar.gz"))
        (sha256 (base32 "1r1w2n1ndj5psvpm87ij6gwr0hwrbsn6gllv4q44spbvq2spizvz"))
      )
    )
    (home-page "https://apptainer.org/")
    (synopsis "THE CONTAINER SYSTEM FOR SECURE HIGH PERFORMANCE COMPUTING")
    (description "Apptainer/Singularity is the most widely used container system for HPC.
                  It is designed to execute applications at bare-metal performance while
                  being secure, portable, and 100% reproducible. Apptainer is an 
                  open-source project with a friendly community of developers and users.
                  The user base continues to expand, with Apptainer/Singularity now used
                  across industry and academia in many areas of work."
    )
    (license license:bsd-3)
    (build-system gnu-build-system)
    (inputs `(
      ("libarchive", libarchive)
      ("python", python-wrapper)
      ("zlib", zlib)
      ("squashfs-tools", squashfs-tools)
      ("openssl", openssl)
      ("libseccomp", gnu:libseccomp)
      ("cryptsetup", cryptsetup)
      ("go", go-1.17)
      ("pkg-config", pkg-config)
    ))
    (arguments
      `(#:phases
        (modify-phases %standard-phases
          (replace 'configure
            (lambda* (#:key inputs native-inputs propagated-inputs configure-flags #:allow-other-keys)
              (begin
                (invoke "./mconfig" "--localstatedir=/var")
              )
            )
          )
        )
      )
    )
  )
)
